import ModalFactory from 'core/modal_factory';
import ModalEvents from 'core/modal_events';
import {activityHasStartedReports} from './repository';

export const init = (title, messageWithReport, messagewithreportconfirmed, messageWithoutReport) => {
    /**
     * Shows a modal cancel dialog
     * @param {string} title
     * @param {string} message
     * @param {callback} callback
     * @return {modal}
     */
    async function cancelDialog(title, message, callback) {
        const modal = await ModalFactory.create({
            type: ModalFactory.types.DELETE_CANCEL,
            title: title,
            body: message,
        });
        await modal.show();
        modal.getRoot().on(ModalEvents.delete, callback);
        return modal;
    }

    /**
     * Handles a delete request on a LabNbook activity.
     * @param {Event} evt
     * @param {DOMElement} elem
     */
    async function deleteHandler(evt, elem) {
        if (deleteHandler.shouldPrevent) {
            evt.preventDefault();
            evt.stopPropagation();
            const activityID = elem.getAttribute('data-id');
            const hasStartedReports = await activityHasStartedReports(activityID);
            if (hasStartedReports) {
                await cancelDialog(
                    title,
                    messageWithReport,
                    async function() {
                        // Show a new modal with messagewithreportconfirmed
                        const modal = await ModalFactory.create({
                            title: title,
                            body: messagewithreportconfirmed,
                        });
                        await modal.show();
                        // Re run event without interception
                        deleteHandler.shouldPrevent = false;
                        elem.dispatchEvent(evt);
                    });
            } else {
                await cancelDialog(
                    title,
                    messageWithoutReport,
                    function() {
                        // Re run event without interception
                        deleteHandler.shouldPrevent = false;
                        elem.dispatchEvent(evt);
                    });
            }
        } else {
            deleteHandler.shouldPrevent = true;
        }
    }
    deleteHandler.shouldPrevent = true;
    document.querySelectorAll('li.labnbook .editing_delete').forEach(function(elem) {
         elem.addEventListener('click', async function(evt) {
             deleteHandler(evt, elem);
         });
     });
};
